from nexo.schemas.resource import Resource, ResourceIdentifier

PARAMETER_RESOURCE = Resource(
    identifiers=[
        ResourceIdentifier(key="parameter", name="Parameter", slug="parameters")
    ],
    details=None,
)
